@@ -2,6 +2,9 @@
 refRes_file <- '../data/refResults.RData'
 load(refRes_file)
 
+#Load data with hidden/excluded assays (all NPX=NA)
+load(file = '../data/npx_data_format221010.RData')
+
 #Run olink_ttest
 t.test_results <- olink_ttest(npx_data1, 'Treatment')
 
@@ -14,4 +17,6 @@ test_that("T-test function works", {
   expect_equal(as.matrix(t.test_results_paired), as.matrix(ref_results$t.test_results_paired))  # compare results to ref
   expect_error(olink_ttest(df = npx_data1)) # no input data
   expect_error(olink_ttest(npx_data1, "Time")) # more than 2 levels in the grouping variable
+
+  expect_warning(olink_ttest(npx_data_format221010, 'treatment1')) # data with all NPX=NA for some assays
 })
