@@ -4,6 +4,7 @@ test_that("Data loads correctly with 'read_NPX()'", {
   manifest_file <- system.file("extdata", "npx_data1_meta.csv", package = "OlinkAnalyze", mustWork = TRUE)
   df_1 <- read_NPX(filename = npx_file) # load dataset 1
   manifest_1 <- read.delim(manifest_file, header = TRUE, sep = ';') # load manifest 1
+  df_2_2 <- read_NPX(system.file("extdata", "Example_NPX_Data2_1.csv", package = "OlinkAnalyze", mustWork = TRUE))
 
   #NPX read ok?
   expect(exists("df_1"), failure_message = "read_NPX failed on dataset 1")
@@ -42,6 +43,10 @@ test_that("Data loads correctly with 'read_NPX()'", {
                    c("SampleID", "Index", "OlinkID", "UniProt", "Assay",
                      "MissingFreq", "Panel","Panel_Lot_Nr", "PlateID", "QC_Warning", "LOD",
                      "NPX", "Normalization", "Assay_Warning"))
+  expect_identical(colnames(df_2_2),
+                   c("SampleID", "Index", "OlinkID", "UniProt", "Assay",
+                     "MissingFreq", "Panel","Panel_Lot_Nr", "PlateID", "QC_Warning", "LOD",
+                     "NPX", "Normalization"))
 
   #All samples in the manifest?
   sample_names <- df_1 %>%
@@ -69,3 +74,28 @@ test_that("data completeness check", {
   )
 
 })
+
+
+# Sample ID with # --------------------------------------------------------
+
+
+test_that("# in SampleID", {
+      input <- read_NPX(testthat::test_path("refs/mock_sampleID_hashes.csv"))
+
+      expect_equal(input$SampleID, c("Sample#1", "Sample_#31"))
+})
+
+
+
+# Flex long format QUANT xlsx ---------------------------------------------
+
+
+test_that("# in SampleID", {
+  expect_message(
+    input <- read_NPX(
+      testthat::test_path("refs/Flex_test_data_long_quant.xlsx")),
+    "Flex data in long form detected"
+  )
+
+  expect_equal(input$Quantified_value, c(0.19169, 336.12903))
+})
